from enum import Enum


class AccountType(Enum):
    DEBIT_CARD = 3
    PHONE_NUMBER = 10
    CLABE = 40


class Prioridad(Enum):
    normal = 0
    alta = 1


class Institucion(Enum):
    BANCOMEXT = 37006
    BANOBRAS = 37009
    BANJERCITO = 37019
    NAFIN = 37135
    BANSEFI = 37166
    HIPOTECARIAFEDERAL = 37168
    BANAMEX = 40002
    BBVA_BANCOMER = 40012
    SANTANDER = 40014
    HSBC = 40021
    BAJIO = 40030
    INBURSA = 40036
    INTERACCIONES = 40037
    MIFEL = 40042
    SCOTIABANK = 40044
    BANREGIO = 40058
    INVEX = 40059
    BANSI = 40060
    AFIRME = 40062
    BANORTE = 40072
    INVESTA_BANK = 40102
    AMERICANEXPRESS = 40103
    BAMSA = 40106
    TOKYO = 40108
    JPMORGAN = 40110
    BMONEX = 40112
    VEPORMAS = 40113
    DEUTSCHE = 40124
    CREDITSUISSE = 40126
    AZTECA = 40127
    AUTOFIN = 40128
    BARCLAYS = 40129
    COMPARTAMOS = 40130
    FAMSA = 40131
    MULTIVA_BANCO = 40132
    ACTINVER = 40133
    INTERCAM = 40136
    BANCOPPEL = 40137
    ABCCAPITAL = 40138
    CONSUBANCO = 40140
    VOLKSWAGEN = 40140
    CIBANCO = 40143
    BBASE = 40145
    BANKAOOL = 40147
    PAGATODO = 40148
    INMOBILIARIO = 40150
    DONDE = 40151
    BACREA = 40152
    BANCO_FINTERRA = 40154
    ICBC = 40155
    SABADELL = 40156
    MIZUHO_BANK = 40156
    MONEXCB = 90600
    GBP = 90601
    MASARI = 90602
    VALUE = 90605
    ESTRUCTURADORES = 90606
    VECTOR = 90608
    MULTIVA_CBOLSA = 90613
    ACCIVAL = 90614
    FINAMEX = 90616
    VALMEX = 90617
    PROFUTURO = 90620
    CB_ACTINVER = 90621
    SKANDIAVIDA = 90623
    CBDEUTSCHE = 90626
    ZURICH = 90627
    ZURICHVI = 90628
    CBINTERCAM = 90630
    CI_BOLSA = 90631
    FINCOMUN = 90634
    HDI_SEGUROS = 90636
    ORDER = 90637
    AKALA = 90638
    JPMORGANCB = 90640
    REFORMA = 90642
    STP = 90646
    EVERCORE = 90648
    OSKNDIA = 90649
    ASEA = 90652
    KUSPIT = 90653
    SOFIEXPRESS = 90655
    UNAGRA = 90656
    ASP_INTEGRA_OPC = 90659
    LIBERTAD = 90670
    HUASTECAS = 90671
    AXA = 90674
    CAJA_POP_MEXICA = 90677
    SURA = 90678
    FND = 90679
    CRISTOBAL_COLON = 90680
    PRINCIPAL = 90681
    CAJA_TELEFONIST = 90683
    TRANSFER = 90684
    FONDO_FIRA = 90685
    INVERCAP = 90686
    INFONAVIT = 90687
    FOMPED = 90689
    CLS = 90901
    INDEVAL = 90902
